from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.api_external_function import ApiExternalFunction
    from ..models.api_table import ApiTable


T = TypeVar("T", bound="ApiWorkspace")


@attr.s(auto_attribs=True)
class ApiWorkspace:
    """
    Attributes:
        name (str):
        external_functions (Union[Unset, List['ApiExternalFunction']]):
        tables (Union[Unset, List['ApiTable']]):
    """

    name: str
    external_functions: Union[Unset, List["ApiExternalFunction"]] = UNSET
    tables: Union[Unset, List["ApiTable"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        external_functions: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.external_functions, Unset):
            external_functions = []
            for external_functions_item_data in self.external_functions:
                external_functions_item = external_functions_item_data.to_dict()

                external_functions.append(external_functions_item)

        tables: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.tables, Unset):
            tables = []
            for tables_item_data in self.tables:
                tables_item = tables_item_data.to_dict()

                tables.append(tables_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
            }
        )
        if external_functions is not UNSET:
            field_dict["externalFunctions"] = external_functions
        if tables is not UNSET:
            field_dict["tables"] = tables

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_external_function import ApiExternalFunction
        from ..models.api_table import ApiTable

        d = src_dict.copy()
        name = d.pop("name")

        external_functions = []
        _external_functions = d.pop("externalFunctions", UNSET)
        for external_functions_item_data in _external_functions or []:
            external_functions_item = ApiExternalFunction.from_dict(external_functions_item_data)

            external_functions.append(external_functions_item)

        tables = []
        _tables = d.pop("tables", UNSET)
        for tables_item_data in _tables or []:
            tables_item = ApiTable.from_dict(tables_item_data)

            tables.append(tables_item)

        api_workspace = cls(
            name=name,
            external_functions=external_functions,
            tables=tables,
        )

        api_workspace.additional_properties = d
        return api_workspace

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.api_column import ApiColumn


T = TypeVar("T", bound="ApiTable")


@attr.s(auto_attribs=True)
class ApiTable:
    """
    Attributes:
        name (str):
        position (int):
        columns (Union[Unset, List['ApiColumn']]):
    """

    name: str
    position: int
    columns: Union[Unset, List["ApiColumn"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        position = self.position
        columns: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.columns, Unset):
            columns = []
            for columns_item_data in self.columns:
                columns_item = columns_item_data.to_dict()

                columns.append(columns_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "position": position,
            }
        )
        if columns is not UNSET:
            field_dict["columns"] = columns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_column import ApiColumn

        d = src_dict.copy()
        name = d.pop("name")

        position = d.pop("position")

        columns = []
        _columns = d.pop("columns", UNSET)
        for columns_item_data in _columns or []:
            columns_item = ApiColumn.from_dict(columns_item_data)

            columns.append(columns_item)

        api_table = cls(
            name=name,
            position=position,
            columns=columns,
        )

        api_table.additional_properties = d
        return api_table

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiExternalFunction")


@attr.s(auto_attribs=True)
class ApiExternalFunction:
    """
    Attributes:
        function_name (str):
        return_type (str):
        parameter_types (Union[Unset, List[str]]):
    """

    function_name: str
    return_type: str
    parameter_types: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        function_name = self.function_name
        return_type = self.return_type
        parameter_types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.parameter_types, Unset):
            parameter_types = self.parameter_types

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "functionName": function_name,
                "returnType": return_type,
            }
        )
        if parameter_types is not UNSET:
            field_dict["parameterTypes"] = parameter_types

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        function_name = d.pop("functionName")

        return_type = d.pop("returnType")

        parameter_types = cast(List[str], d.pop("parameterTypes", UNSET))

        api_external_function = cls(
            function_name=function_name,
            return_type=return_type,
            parameter_types=parameter_types,
        )

        api_external_function.additional_properties = d
        return api_external_function

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .add_data_column_type import AddDataColumnType
from .api_column import ApiColumn
from .api_external_function import ApiExternalFunction
from .api_table import ApiTable
from .api_table_data import ApiTableData
from .api_workspace import ApiWorkspace
from .create_external_function_return_type import CreateExternalFunctionReturnType
from .create_external_function_runtime import CreateExternalFunctionRuntime
from .get_table_upload_csv_url_mode import GetTableUploadCsvUrlMode
from .presigned_url import PresignedUrl
from .table_row import TableRow

__all__ = (
    "AddDataColumnType",
    "ApiColumn",
    "ApiExternalFunction",
    "ApiTable",
    "ApiTableData",
    "ApiWorkspace",
    "CreateExternalFunctionReturnType",
    "CreateExternalFunctionRuntime",
    "GetTableUploadCsvUrlMode",
    "PresignedUrl",
    "TableRow",
)



import pathlib

from setuptools import find_packages, setup

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

REQUIRES = [
    "httpx >= 0.15.0, < 0.24.0",
    "attrs >= 21.3.0",
    "python-dateutil >= 2.8.0, < 3",
    "boto3~=1.24.78",
    "requests==2.25",
    "frozendict==2.3.4",
    "pandas==1.5.2",
]

setup(
    name="priceloop-api",
    version="0.54.0",
    description="A client library for accessing Priceloop API",
    author="Priceloop",
    author_email="hello@priceloop.ai",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/priceloop/priceloop-api-python",
    packages=find_packages(),
    python_requires=">=3.7, <4",
    install_requires=REQUIRES,
    package_data={"priceloop_api": ["py.typed"]},
)



from enum import Enum


class CreateExternalFunctionRuntime(str, Enum):
    PYTHON = "python"
    PYTHON_NUMPY = "python_numpy"
    PYTHON_PANDAS = "python_pandas"
    NODEJS = "nodejs"
    GO = "go"

    def __str__(self) -> str:
        return str(self.value)
